import { select } from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

// Sky Background
svg
  .append('rect')
  .attr('width', width)
  .attr('height', height)
  .attr('fill', 'skyblue');

// Sun
svg
  .append('circle')
  .attr('cx', 700)
  .attr('cy', 100)
  .attr('r', 50)
  .attr('fill', 'yellow');

// Mountain
const mountainPoints = [
  [300, height],
  [400, 200],
  [500, height],
];
svg
  .append('polygon')
  .attr('points', mountainPoints.join(' '))
  .attr('fill', 'grey');

// River
svg
  .append('path')
  .attr('d', `M0,${height - 100} q150,-50 300,0 t300,0`)
  .attr('fill', 'none')
  .attr('stroke', 'blue')
  .attr('stroke-width', '80');

// Trees
function drawTree(x, y) {
  // Trunk
  svg
    .append('rect')
    .attr('x', x - 10)
    .attr('y', y)
    .attr('width', 20)
    .attr('height', 50)
    .attr('fill', 'saddlebrown');

  // Leaves
  svg
    .append('circle')
    .attr('cx', x)
    .attr('cy', y)
    .attr('r', 30)
    .attr('fill', 'green');
}

drawTree(100, 400);
drawTree(200, 450);
drawTree(800, 400);

// Birds - Simplified with triangles
function drawBird(x, y) {
  svg
    .append('polygon')
    .attr(
      'points',
      `${x},${y} ${x - 15},${y + 10} ${x + 15},${y + 10}`,
    )
    .attr('fill', 'black');
}

drawBird(600, 150);
drawBird(650, 120);
drawBird(700, 180);
